==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/admin_quick_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   admin_quick_edit.lang.inc.php 2016-08-16
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2016 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	// Common
	'PAGE_TITLE'                       => 'QuickEdit',
	'SETTINGS'                         => 'Einstellungen',
	'PROPERTIES'                       => 'Eigenschaften',
	'CONFIGURATION'                    => 'Konfiguration',
	'OVERVIEW'                         => 'Übersicht',
	'INVENTORY_CHECKLIST'              => 'Inventar Checkliste',
	'IS'                               => 'Ist',
	'SHOULD'                           => 'Soll',
	'CREATED_AT'                       => 'Erstellt am',
	'ACTIVE'                           => 'Aktiv',
	'INACTIVE'                         => 'Inaktiv',
	'SEARCH'                           => 'Suchen',
	'TEXT_MODE'                        => 'Modus',
	'TEXT_FILTER_MODE'                 => 'Filtern',
	'TEXT_EDIT_MODE'                   => 'Editieren',
	'TEXT_PLEASE_WAIT'                 => 'Bitte warten',
	'TEXT_READY_TO_DOWNLOAD_DOCUMENT'  => 'Das Dokument kann jetzt heruntergeladen werden',
	'NO_RESULTS_FOR'                   => 'Keine Ergebnisse für',
	'NUMBER_OF_PIECES'                 => 'Stückzahl',
	'UNEXPECTED_REQUEST_ERROR'         => 'Unerwartete Fehler beim Abfrage.',
	// Table Column Title
	'ID'                               => 'ID',
	'CATEGORY'                         => 'Kategorie',
	'MANUFACTURER'                     => 'Hersteller',
	'MODEL'                            => 'Artikel-Nr.',
	'NAME'                             => 'Artikel',
	'COMBINATION'                      => 'Kombination',
	'QUANTITY'                         => 'Lager',
	'SHIPPINGTIME'                     => 'Lieferzeit',
	'WEIGHT'                           => 'Gewicht',
	'SHIPPINGCOSTS'                    => 'Versandkosten',
	'TAX'                              => 'Steuersatz',
	'PRICE'                            => 'Artikelpreis',
	'PRICETYPE'                        => 'Preistyp',
	'COMBI_PRICE'                      => 'Preis',
	'DISCOUNT'                         => 'Rabatt',
	'SPECIAL_PRICE'                    => 'Angebotspreis',
	'SPECIAL_QUANTITY'                 => 'Anzahl',
	'EXPIRES_DATE'                     => 'Gültig bis',
	'STATUS'                           => 'Status',
	'ACTIONS'                          => 'Aktionen',
	// Modal Titles
	'MODAL_TITLE_NODE'                 => 'Hinweis',
	'MODAL_TITLE_SETTINGS'             => 'Einstellungen',
	'MODAL_TITLE_PROPERTIES'           => 'Eigenschaften',
	'MODAL_TITLE_SPECIAL_PRICE'        => 'Sonderangebot',
	'MODAL_TITLE_GRADUATED_PRICES'     => 'Staffelpreise',
	'MODAL_TITLE_DOCUMENT_CREATE'      => 'Dokument erstellen',
	// Modal Settings
	'COLUMN'                           => 'Spalte',
	'COLUMNS'                          => 'Spalten',
	'ROWS'                             => 'Zeilen',
	'ROW_HEIGHT_LABEL'                 => 'Höhe',
	'ROW_HEIGHT_SMALL'                 => 'Klein',
	'ROW_HEIGHT_MEDIUM'                => 'Mittel',
	'ROW_HEIGHT_LARGE'                 => 'Groß',
	// Modal Exceptions
	'NO_PRODUCT_SELECTED'              => 'Es wurden keine Artikel für eine Änderung ausgewählt.',
	'NOTHING_TO_EDIT'                  => 'Es wurden keine Änderungen für die ausgewählten Artikel erkannt.',
	'EDIT_ERROR'                       => 'Änderungen konnten nicht gespeichert werden.',
	// Buttons
	'BUTTON_SHOW'                      => 'Anzeigen',
	'BUTTON_EDIT'                      => 'Bearbeiten',
	'BUTTON_PROPERTIES'                => 'Eigenschaften',
	'BUTTON_GRADUATED_PRICES'          => 'Staffelpreise',
	'BUTTON_SPECIAL_PRICE'             => 'Sonderangebot',
	'BUTTON_SAVE'                      => 'Speichern',
	'BUTTON_CANCEL'                    => 'Abbrechen',
	'BUTTON_CLOSE'                     => 'Schliessen',
	'BUTTON_CREATE'                    => 'Erstellen',
	'BUTTON_DOWNLOAD'                  => 'Herunterladen',
	'BUTTON_DELETE'                    => 'Löschen',
	'BUTTON_FILTER'                    => 'Filtern',
	'BUTTON_INVENTORY_DOCUMENT_CREATE' => 'Inventarliste erstellen',
	'BUTTON_RESET'                     => 'Zurücksetzen',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Auf Standardeinstellung zurücksetzen',
	// Tooltips
	'TOOLTIP_FILTER_CATEGORY'          => 'Wildcard-Suche mit (*) z.B.: *amp*',
	'TOOLTIP_FILTER_NAME'              => 'Wildcard-Suche mit (*) z.B.: 4*1*',
	'TOOLTIP_FILTER_MODEL'             => 'Wildcard-Suche mit (*) z.B.: K*27*',
	'TOOLTIP_FILTER_QUANTITY'          => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_PRICE'             => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_DISCOUNT'          => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_SPECIAL_PRICE'     => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_WEIGHT'            => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_SHIPPING_COSTS'    => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_NAME'        => 'Wildcard-Suche mit (*) z.B.: *amp*',
	'TOOLTIP_FILTER_COMBI_MODEL'       => 'Wildcard-Suche mit (*) z.B.: K*27*',
	'TOOLTIP_FILTER_COMBI_EAN'         => 'Wildcard-Suche mit (*) z.B.: *123*',
	'TOOLTIP_FILTER_COMBI_QUANTITY'    => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_WEIGHT'      => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_PRICE'       => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_EDIT_QUANTITY'            => 'Editierwerte z.B.: (10), (-10 oder +10) und (-10% oder +10%)',
	'TOOLTIP_EDIT_PRICE'               => 'Editierwerte z.B.: (20), (-20 oder +20) und (-20% oder +20%)',
	'TOOLTIP_EDIT_DISCOUNT'            => 'Editierwerte z.B.: (30)',
	'TOOLTIP_EDIT_SPECIAL_PRICE'       => 'Editierwerte z.B.: (40), (-40 oder +40), (40%), (-40% oder +40%)<br> WICHTIG: Eingabe von Prozentwert (%) ohne minus(-) oder plus(+) bezieht sich auf den Artikelpreis!',
	'TOOLTIP_EDIT_WEIGHT'              => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_SHIPPING_COSTS'      => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_COMBI_QUANTITY'      => 'Editierwerte z.B.: (10), (-10 oder +10) und (-10% oder +10%)',
	'TOOLTIP_EDIT_COMBI_WEIGHT'        => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_COMBI_PRICE'         => 'Editierwerte z.B.: (20), (-20 oder +20) und (-20% oder +20%)',
	'TOOLTIP_NO_CHANGES'               => 'Keine Änderung',
	// Admin info box
	'SUCCESS_PRODUCT_UPDATED'          => 'Änderungen wurden erfolgreich aktualisiert.',
	// Products Properties
	'COMBI_FIX_PRICE'                  => 'Festpreis',
	'COMBI_CALC_PRICE'                 => 'Berechnen',
	// Specials
	'TEXT_DATE_OF_EXPIRY'              => 'Gültig bis:',
	'TEXT_QUANTITY'                    => 'Anzahl:',
	'TEXT_NEW_PRICE'                   => 'Neuer Preis:',
	'TEXT_SURCHARGE'                   => 'Aufschlag:',
	'TEXT_DISCOUNT'                    => 'Abschlag:',
	'TEXT_STATUS'                      => 'Status:',
	'TEXT_NO_SPECIAL_OFFER'            => 'Kein Sonderangebot konfiguriert',
	'TEXT_TITLE_SPECIAL_OFFER'         => 'Sonderangebot',
	'TEXT_X_TO_X'                      => '# von #',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_quick_edit.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   admin_quick_edit.lang.inc.php 2021-09-23
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
	// Common
	'PAGE_TITLE'                       => 'QuickEdit',
	'SETTINGS'                         => 'Einstellungen',
	'PROPERTIES'                       => 'Artikelvarianten',
	'CONFIGURATION'                    => 'Konfiguration',
	'OVERVIEW'                         => 'Übersicht',
	'INVENTORY_CHECKLIST'              => 'Inventar Checkliste',
	'IS'                               => 'Ist',
	'SHOULD'                           => 'Soll',
	'CREATED_AT'                       => 'Erstellt am',
	'ACTIVE'                           => 'Aktiv',
	'INACTIVE'                         => 'Inaktiv',
	'SEARCH'                           => 'Suchen',
    'UNCATEGORIZED'                    => 'Nicht kategorisiert',
	'TEXT_MODE'                        => 'Modus',
	'TEXT_FILTER_MODE'                 => 'Filtern',
	'TEXT_EDIT_MODE'                   => 'Editieren',
	'TEXT_PLEASE_WAIT'                 => 'Bitte warten',
	'TEXT_READY_TO_DOWNLOAD_DOCUMENT'  => 'Das Dokument kann jetzt heruntergeladen werden',
	'NO_RESULTS_FOR'                   => 'Keine Ergebnisse für',
	'NUMBER_OF_PIECES'                 => 'Stückzahl',
	'UNEXPECTED_REQUEST_ERROR'         => 'Unerwartete Fehler beim Abfrage.',
	// Table Column Title
	'ID'                               => 'ID',
	'CATEGORY'                         => 'Kategorie',
	'MANUFACTURER'                     => 'Hersteller',
	'MODEL'                            => 'Artikel-Nr.',
	'NAME'                             => 'Artikel',
	'COMBINATION'                      => 'Kombination',
	'QUANTITY'                         => 'Lager',
	'SHIPPINGTIME'                     => 'Lieferzeit',
	'WEIGHT'                           => 'Gewicht',
	'SHIPPINGCOSTS'                    => 'Versandkosten',
	'TAX'                              => 'Steuersatz',
	'PRICE'                            => 'Artikelpreis',
	'PRICETYPE'                        => 'Preistyp',
	'COMBI_PRICE'                      => 'Preis',
	'DISCOUNT'                         => 'Rabatt',
	'SPECIAL_PRICE'                    => 'Angebotspreis',
	'SPECIAL_QUANTITY'                 => 'Anzahl',
	'EXPIRES_DATE'                     => 'Gültig bis',
	'STATUS'                           => 'Status',
	'ACTIONS'                          => 'Aktionen',
	// Modal Titles
	'MODAL_TITLE_NODE'                 => 'Hinweis',
	'MODAL_TITLE_SETTINGS'             => 'Einstellungen',
	'MODAL_TITLE_PROPERTIES'           => 'Artikelvarianten',
	'MODAL_TITLE_SPECIAL_PRICE'        => 'Sonderangebot',
	'MODAL_TITLE_GRADUATED_PRICES'     => 'Staffelpreise',
	'MODAL_TITLE_DOCUMENT_CREATE'      => 'Dokument erstellen',
	// Modal Settings
	'COLUMN'                           => 'Spalte',
	'COLUMNS'                          => 'Spalten',
	'ROWS'                             => 'Zeilen',
	'ROW_HEIGHT_LABEL'                 => 'Höhe',
	'ROW_HEIGHT_SMALL'                 => 'Klein',
	'ROW_HEIGHT_MEDIUM'                => 'Mittel',
	'ROW_HEIGHT_LARGE'                 => 'Groß',
	// Modal Exceptions
	'NO_PRODUCT_SELECTED'              => 'Es wurden keine Artikel für eine Änderung ausgewählt.',
	'NOTHING_TO_EDIT'                  => 'Es wurden keine Änderungen für die ausgewählten Artikel erkannt.',
	'EDIT_ERROR'                       => 'Änderungen konnten nicht gespeichert werden.',
	// Buttons
	'BUTTON_SHOW'                      => 'Anzeigen',
	'BUTTON_EDIT'                      => 'Bearbeiten',
	'BUTTON_PROPERTIES'                => 'Artikelvarianten',
	'BUTTON_GRADUATED_PRICES'          => 'Staffelpreise',
	'BUTTON_SPECIAL_PRICE'             => 'Sonderangebot',
	'BUTTON_SAVE'                      => 'Speichern',
	'BUTTON_CANCEL'                    => 'Abbrechen',
	'BUTTON_CLOSE'                     => 'Schliessen',
	'BUTTON_CREATE'                    => 'Erstellen',
	'BUTTON_DOWNLOAD'                  => 'Herunterladen',
	'BUTTON_DELETE'                    => 'Löschen',
	'BUTTON_FILTER'                    => 'Filtern',
	'BUTTON_INVENTORY_DOCUMENT_CREATE' => 'Inventarliste erstellen',
	'BUTTON_RESET'                     => 'Zurücksetzen',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Auf Standardeinstellung zurücksetzen',
	// Tooltips
	'TOOLTIP_FILTER_CATEGORY'          => 'Wildcard-Suche mit (*) z.B.: *amp*',
	'TOOLTIP_FILTER_NAME'              => 'Wildcard-Suche mit (*) z.B.: 4*1*',
	'TOOLTIP_FILTER_MODEL'             => 'Wildcard-Suche mit (*) z.B.: K*27*',
	'TOOLTIP_FILTER_QUANTITY'          => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_PRICE'             => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_DISCOUNT'          => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_SPECIAL_PRICE'     => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_WEIGHT'            => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_SHIPPING_COSTS'    => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_NAME'        => 'Wildcard-Suche mit (*) z.B.: *amp*',
	'TOOLTIP_FILTER_COMBI_MODEL'       => 'Wildcard-Suche mit (*) z.B.: K*27*',
	'TOOLTIP_FILTER_COMBI_EAN'         => 'Wildcard-Suche mit (*) z.B.: *123*',
	'TOOLTIP_FILTER_COMBI_QUANTITY'    => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_WEIGHT'      => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_FILTER_COMBI_PRICE'       => 'Filterwerte z.B.: (1), (2-3), (<4 oder 4>) und (>5 oder 5<)',
	'TOOLTIP_EDIT_QUANTITY'            => 'Editierwerte z.B.: (10), (-10 oder +10) und (-10% oder +10%)',
	'TOOLTIP_EDIT_PRICE'               => 'Editierwerte z.B.: (20), (-20 oder +20) und (-20% oder +20%)',
	'TOOLTIP_EDIT_DISCOUNT'            => 'Editierwerte z.B.: (30)',
	'TOOLTIP_EDIT_SPECIAL_PRICE'       => 'Editierwerte z.B.: (40), (-40 oder +40), (40%), (-40% oder +40%)<br> WICHTIG: Eingabe von Prozentwert (%) ohne minus(-) oder plus(+) bezieht sich auf den Artikelpreis!',
	'TOOLTIP_EDIT_WEIGHT'              => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_SHIPPING_COSTS'      => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_COMBI_QUANTITY'      => 'Editierwerte z.B.: (10), (-10 oder +10) und (-10% oder +10%)',
	'TOOLTIP_EDIT_COMBI_WEIGHT'        => 'Editierwerte z.B.: (5), (-5 oder +5) und (-5% oder +5%)',
	'TOOLTIP_EDIT_COMBI_PRICE'         => 'Editierwerte z.B.: (20), (-20 oder +20) und (-20% oder +20%)',
	'TOOLTIP_NO_CHANGES'               => 'Keine Änderung',
	// Admin info box
	'SUCCESS_PRODUCT_UPDATED'          => 'Änderungen wurden erfolgreich aktualisiert.',
	// Products Properties
	'COMBI_FIX_PRICE'                  => 'Festpreis',
	'COMBI_CALC_PRICE'                 => 'Berechnen',
	// Specials
	'TEXT_DATE_OF_EXPIRY'              => 'Gültig bis:',
	'TEXT_QUANTITY'                    => 'Anzahl:',
	'TEXT_NEW_PRICE'                   => 'Neuer Preis:',
	'TEXT_SURCHARGE'                   => 'Aufschlag:',
	'TEXT_DISCOUNT'                    => 'Abschlag:',
	'TEXT_STATUS'                      => 'Status:',
	'TEXT_NO_SPECIAL_OFFER'            => 'Kein Sonderangebot konfiguriert',
	'TEXT_TITLE_SPECIAL_OFFER'         => 'Sonderangebot',
	'TEXT_X_TO_X'                      => '# von #',
];
